MockFdpBackend

Struct MockFdpBackend 

pub struct MockFdpBackend {
    pub recorded_hints: Mutex<Vec<(PathBuf, u64, PlacementHint)>>,
    /* private fields */
}
Mock FDP backend that records placement hints for test verification.

Fields

recorded_hints: Mutex<Vec<(PathBuf, u64, PlacementHint)>>

Hints recorded by this mock backend for test verification.

Implementations

Source

impl MockFdpBackend

pub fn new(inner: Box<dyn StorageBackend>) -> Self

Create a new mock backend wrapping the given inner backend.