Transaction

Struct Transaction 

pub struct Transaction { /* private fields */ }
Multi-record atomic transaction batch.

Implementations

Source

impl Transaction

pub fn new(txid: u64) -> Self

Create a new empty transaction with the given txid.

pub fn put( &mut self, ns: &[u8], key: &[u8], val: &[u8], lsn: Lsn, timestamp: i64, ) -> Result<(), EdgestoreError>

Append a put operation to this transaction.

pub fn put_with_ttl( &mut self, ns: &[u8], key: &[u8], val: &[u8], ttl_secs: u32, lsn: Lsn, timestamp: i64, ) -> Result<(), EdgestoreError>

Append a put-with-TTL operation to this transaction.

pub fn delete( &mut self, ns: &[u8], key: &[u8], lsn: Lsn, timestamp: i64, ) -> Result<(), EdgestoreError>

Append a delete operation to this transaction.

pub fn rollback_self(&mut self)

Roll back this transaction, clearing all pending records.

pub fn take_pending(&mut self) -> Result<Vec<WalRecord>, EdgestoreError>

Take ownership of pending records, marking this transaction committed.

pub fn is_active(&self) -> bool

Returns true if this transaction is still active.

pub fn commit(self, engine: &mut Engine) -> Result<Lsn, EdgestoreError>

Convenience wrapper: commit via engine.

pub fn rollback(self, engine: &mut Engine)

Convenience wrapper: rollback via engine.